@@ -33,8 +33,20 @@ class Resource(models.Model):
                 employees.append(employment.resource)
         return employees
 
-    def main_position(self):
-        return self.employments.filter(mainPosition=True).first()
+    def main_position(self, assume: bool = False):
+        """
+        Get the resources main position
+        :type assume: bool Assume that the main position is the one with the
+        highest percentage if main position is not specified
+        :rtype: Employment
+        """
+        employments = self.employments.filter(mainPosition=True).first()
+        if not employments:
+            if assume:
+                employments = self.employments.order_by('percentage')
+                return employments.last()
+        else:
+            return employments
 
     def __str__(self):
         return '%s %s' % (self.firstName, self.lastName)
@@ -62,7 +74,7 @@ class CostCenter(models.Model):
 class WorkPlace(models.Model):
     company = models.ForeignKey(Company, on_delete=models.PROTECT, verbose_name='firma', related_name='work_places')
     value = models.CharField('verdi', max_length=4)
-    description = models.CharField('beskrivelse', max_length=200)
+    description = models.CharField('beskrivelse', max_length=200, null=True, blank=True)
 
     def __str__(self):
         return '%s %s (%s)' % (self.value, self.description, self.company.companyCode)
@@ -76,7 +88,7 @@ class WorkPlace(models.Model):
 class Function(models.Model):
     company = models.ForeignKey(Company, on_delete=models.PROTECT, verbose_name='firma', related_name='functions')
     value = models.CharField('verdi', max_length=4)
-    description = models.CharField('beskrivelse', max_length=200)
+    description = models.CharField('beskrivelse', max_length=200, null=True, blank=True)
 
     def __str__(self):
         return '%s %s (%s)' % (self.value, self.description, self.company.companyCode)
@@ -91,9 +103,9 @@ class Organisation(models.Model):
     company = models.ForeignKey(Company, on_delete=models.PROTECT, verbose_name='firma', related_name='organisation')
     name = models.CharField('navn', max_length=200)
     orgId = models.CharField('nummer', max_length=6)
-    parent = models.ForeignKey('self', on_delete=models.PROTECT, verbose_name='overordnet', related_name='children',
+    parent = models.ForeignKey('self', on_delete=models.SET_NULL, verbose_name='overordnet', related_name='children',
                                null=True)
-    manager = models.ForeignKey(Resource, on_delete=models.PROTECT, verbose_name='leder', related_name='manages',
+    manager = models.ForeignKey(Resource, on_delete=models.SET_NULL, verbose_name='leder', related_name='manages',
                                 null=True)
     status = models.CharField(max_length=1)
 
@@ -115,7 +127,7 @@ class Employment(models.Model):
     postId = models.IntegerField()
     postIdDescription = models.CharField(max_length=200)
     postCode = models.IntegerField('stillingskode')
-    postCodeDescription = models.CharField(max_length=200)
+    postCodeDescription = models.CharField(max_length=200, null=True, blank=True)
 
     dateFrom = models.DateField('dato fra')
     dateTo = models.DateField('dato til')
